@@ -49,8 +49,6 @@ class RabbitMQConsumer(metaclass=ABCMeta):
                     await self.on_finish()
                     if self.consuming_flag:
                         await asyncio.sleep(self.iterator_timeout_sleep)
-                except Exception:
-                    self.stop_consuming()
                 finally:
                     await self.on_finish()
 
