@@ -70,8 +70,10 @@ async def run_consumer(consumer_class: RabbitMQConsumer,
                        binding: str,
                        dl_enabled: Optional[bool] = False,
                        dl_queue_name: Optional[str] = None,
+                       dl_queue_params: Optional[dict] = {},
                        dl_exchange_name: Optional[str] = None,
                        dl_exchange_type: Optional[str] = None,
+                       dl_exchange_params: Optional[dict] = {},
                        dl_bindings: Optional[list] = []) -> None:
     loop = asyncio.get_event_loop()
 
@@ -92,8 +94,8 @@ async def run_consumer(consumer_class: RabbitMQConsumer,
                                                                                        dl_queue_name,
                                                                                        dl_exchange_name,
                                                                                        get_exchange_type(dl_exchange_type),
-                                                                                       default_queue_params,
-                                                                                       default_exchange_params,
+                                                                                       dl_queue_params,
+                                                                                       dl_exchange_params,
                                                                                        dl_bindings)
         queue = await _prepare_consumed_queue(channel,
                                               queue_name,
